Learn R Programming

phaseR (version 2.0)

lotkaVolterra: The Lotka Volterra Model

Description

The derivative function of the Lotka Volterra model, an example of a two-dimensional autonomous ODE system.

Usage

lotkaVolterra(t, y, parameters)

Arguments

t

The value of , the independent variable, to evaluate the derivative at. Should be a single number.

y

The values of and , the dependent variables, to evaluate the derivative at. Should be a vector of length two.

parameters

The values of the parameters of the system. Should be a vector with parameters specified in the following order: , , , .

Value

Returns a list containing the values of the two derivatives at .

Details

lotkaVolterra evaluates the derivative of the following ODE at the point :

Its format is designed to be compatible with ode from the deSolve package.

See Also

ode