The derivative function of the Lotka Volterra model, an example of a two-dimensional autonomous ODE system.
lotkaVolterra(t, y, parameters)The value of , the independent variable, to evaluate the derivative at. Should be a single number.
The values of and , the dependent variables, to evaluate the derivative at. Should be a vector of length two.
The values of the parameters of the system. Should be a vector with parameters specified in the following order: , , , .
Returns a list containing the values of the two derivatives at .
lotkaVolterra evaluates the derivative of the following ODE at the point
:
Its format is designed to be compatible with ode from the deSolve package.